/**
 * Toasts provide a brief notification to the user.
 * They appear temporarily and shouldn't interrupt the user experience, they don't require user input to disappear.
 *
 * @category Dashboard
 */
export interface Toast {
    /**
     * Display a toast message of type success.
     *
     * ```typescript
     * window.ddClient.desktopUI.toast.success("message");
     * ```
     * @param msg The message to display in the toast.
     */
    success(msg: string): void;
    /**
     * Display a toast message of type warning.
     *
     * ```typescript
     * window.ddClient.desktopUI.toast.warning("message");
     * ```
     * @param msg The message to display in the warning.
     */
    warning(msg: string): void;
    /**
     * Display a toast message of type error.
     *
     * ```typescript
     * window.ddClient.desktopUI.toast.error("message");
     * ```
     * @param msg The message to display in the toast.
     */
    error(msg: string): void;
}
